#[enum_from_functions]Expand description
A procedural macro attribute that generates an enum based on the functions defined in the impl block it annotates.
See the crate documentation for more information.
#[enum_from_functions]A procedural macro attribute that generates an enum based on the functions defined in the impl block it annotates.
See the crate documentation for more information.